.. _install:

===================
Installing Buckaroo
===================

Buckaroo can be installed from ``PyPI``:

.. code-block:: bash

   pip install buckaroo

Once Buckaroo is installed, it can be used as a a Jupyter Lab  extension. See :ref:`using` for information on how to use Buckaroo.
